==> ponyc-0.18.1-1-x86_64.pkg.tar.xz: usr/share/doc/pony/stdlib-docs/docs/ponybench-PonyBench.md <==
# PonyBench

```pony
actor tag PonyBench
```

## Constructors

### create

```pony
new tag create(
  env: Env val)
: PonyBench tag^
```
#### Parameters

*   env: [Env](builtin-Env) val

#### Returns

* [PonyBench](ponybench-PonyBench) tag^

---

## Public Behaviours

### apply\[A: [Any](builtin-Any) #share\]

Benchmark the function `f` by calling it repeatedly and output a simple
average of the total run time over the amount of times `f` is called. This
amount can be set manually as `ops` or to the default value of 0 which will
trigger the benchmark runner to increase the value of `ops` until it is
satisfied with the stability of the benchmark.


```pony
be apply[A: Any #share](
  name: String val,
  f: {(): A ?}[A] val,
  ops: U64 val = 0)
```
#### Parameters

*   name: [String](builtin-String) val
*   f: {(): A ?}[A] val
*   ops: [U64](builtin-U64) val = 0

---

### async\[A: [Any](builtin-Any) #share\]

Benchmark the time taken for the promise returned by `f` to be fulfilled.
If `timeout` is greater than 0, the benchmark will fail if the promise is
not fulfilled within the time given. This check for timeout is done before
the benchmarks are counted towards an average run time.


```pony
be async[A: Any #share](
  name: String val,
  f: {(): Promise[A] ?}[A] val,
  timeout: U64 val = 0,
  ops: U64 val = 0)
```
#### Parameters

*   name: [String](builtin-String) val
*   f: {(): Promise[A] ?}[A] val
*   timeout: [U64](builtin-U64) val = 0
*   ops: [U64](builtin-U64) val = 0

---

## Private Behaviours

### _result

```pony
be _result(
  name: String val,
  ops: U64 val,
  nspo: U64 val)
```
#### Parameters

*   name: [String](builtin-String) val
*   ops: [U64](builtin-U64) val
*   nspo: [U64](builtin-U64) val

---

### _failure

```pony
be _failure(
  name: String val,
  timeout: Bool val)
```
#### Parameters

*   name: [String](builtin-String) val
*   timeout: [Bool](builtin-Bool) val

---

## Private Functions

### _add

```pony
fun ref _add(
  name: String val,
  b: _Benchmark tag)
: None val
```
#### Parameters

*   name: [String](builtin-String) val
*   b: [_Benchmark](ponybench-_Benchmark) tag

#### Returns

* [None](builtin-None) val

---

### _remove

```pony
fun ref _remove(
  name: String val)
: None val
```
#### Parameters

*   name: [String](builtin-String) val

#### Returns

* [None](builtin-None) val

---

### _next

```pony
fun ref _next()
: None val
```

#### Returns

* [None](builtin-None) val

---

==> ponyc-0.21.3-2-x86_64.pkg.tar.xz: usr/share/doc/pony/stdlib-docs/docs/ponybench-PonyBench.md <==
# PonyBench

```pony
actor tag PonyBench
```

## Constructors

### create

```pony
new tag create(
  env: Env val)
: PonyBench tag^
```
#### Parameters

*   env: [Env](builtin-Env) val

#### Returns

* [PonyBench](ponybench-PonyBench) tag^

---

## Public Behaviours

### apply\[A: [Any](builtin-Any) #share\]

Benchmark the function `f` by calling it repeatedly and output a simple
average of the total run time over the amount of times `f` is called. This
amount can be set manually as `ops` or to the default value of 0 which will
trigger the benchmark runner to increase the value of `ops` until it is
satisfied with the stability of the benchmark.


```pony
be apply[A: Any #share](
  name: String val,
  f: {(): A ?}[A] val,
  ops: U64 val = seq)
```
#### Parameters

*   name: [String](builtin-String) val
*   f: {(): A ?}[A] val
*   ops: [U64](builtin-U64) val = seq

---

### async\[A: [Any](builtin-Any) #share\]

Benchmark the time taken for the promise returned by `f` to be fulfilled.
If `timeout` is greater than 0, the benchmark will fail if the promise is
not fulfilled within the time given. This check for timeout is done before
the benchmarks are counted towards an average run time.


```pony
be async[A: Any #share](
  name: String val,
  f: {(): Promise[A] ?}[A] val,
  timeout: U64 val = seq,
  ops: U64 val = seq)
```
#### Parameters

*   name: [String](builtin-String) val
*   f: {(): Promise[A] ?}[A] val
*   timeout: [U64](builtin-U64) val = seq
*   ops: [U64](builtin-U64) val = seq

---

## Private Behaviours

### _result

```pony
be _result(
  name: String val,
  ops: U64 val,
  nspo: U64 val)
```
#### Parameters

*   name: [String](builtin-String) val
*   ops: [U64](builtin-U64) val
*   nspo: [U64](builtin-U64) val

---

### _failure

```pony
be _failure(
  name: String val,
  timeout: Bool val)
```
#### Parameters

*   name: [String](builtin-String) val
*   timeout: [Bool](builtin-Bool) val

---

## Private Functions

### _add

```pony
fun ref _add(
  name: String val,
  b: _Benchmark tag)
: None val
```
#### Parameters

*   name: [String](builtin-String) val
*   b: [_Benchmark](ponybench-_Benchmark) tag

#### Returns

* [None](builtin-None) val

---

### _remove

```pony
fun ref _remove(
  name: String val)
: None val
```
#### Parameters

*   name: [String](builtin-String) val

#### Returns

* [None](builtin-None) val

---

### _next

```pony
fun ref _next()
: None val
```

#### Returns

* [None](builtin-None) val

---
